@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007 Tristan Heaven <tristanheaven@gmail.com>
+ *   Copyright (C) 2007-2008 Tristan Heaven <tristanheaven@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -16,6 +16,10 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#ifdef HAVE_CONFIG_H
+	#include "config.h"
+#endif
+
 #include <stdlib.h>
 #include <stdbool.h>
 #include <string.h>
@@ -26,7 +30,7 @@
 #include "hash.h"
 #include "gui.h"
 
-#define COL_TOTAL (COL_HASH + HASH_N)
+#define COL_N (COL_HASH + HASH_N)
 
 enum {
 	COL_PATH,
@@ -42,8 +46,8 @@ static struct {
 
 void list_init(void)
 {
-	list.view = GTK_TREE_VIEW(gui_widget("treeview"));
-	GType types[COL_TOTAL];
+	list.view = GTK_TREE_VIEW(gui_get_widget("treeview"));
+	GType types[COL_N];
 	GtkTreeViewColumn *col;
 
 	gtk_tree_selection_set_mode(gtk_tree_view_get_selection(list.view),
@@ -62,13 +66,13 @@ void list_init(void)
 		gtk_tree_view_insert_column_with_attributes(list.view, -1, hash[i].name,
 			gtk_cell_renderer_text_new(), "text", COL_HASH + i, NULL);
 
-	for (int i = 0; i < COL_TOTAL; i++) {
+	for (int i = 0; i < COL_N; i++) {
 		types[i] = G_TYPE_STRING;
 		col = gtk_tree_view_get_column(list.view, i);
 		gtk_tree_view_column_set_resizable(col, true);
 	}
 
-	list.store = gtk_list_store_newv(COL_TOTAL, types);
+	list.store = gtk_list_store_newv(COL_N, types);
 	list.model = GTK_TREE_MODEL(list.store);
 
 	gtk_tree_view_set_model(list.view, list.model);
@@ -106,10 +110,10 @@ void list_append_row(const char *path)
 	gtk_list_store_set(list.store, &iter, COL_BASENAME, basename, -1);
 	g_free(basename);
 
-	gtk_widget_set_sensitive(gui_widget("button_hash"), true);
+	gtk_widget_set_sensitive(gui_get_widget("button_hash"), true);
 
-	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(
-		gui_widget("radiomenuitem_file_list")), true);
+	gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(
+		gui_get_object("radiomenuitem_file_list")), true);
 
 	list_clear_digests();
 }
@@ -261,5 +265,5 @@ void list_clear_digests(void)
 void list_clear(void)
 {
 	gtk_list_store_clear(list.store);
-	gtk_widget_set_sensitive(gui_widget("button_hash"), false);
+	gtk_widget_set_sensitive(gui_get_widget("button_hash"), false);
 }
