@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007 Tristan Heaven <tristanheaven@gmail.com>
+ *   Copyright (C) 2007-2008 Tristan Heaven <tristanheaven@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -19,17 +19,7 @@
 #ifndef _MAIN_H_
 #define _MAIN_H_
 
-#include <mhash.h>
-// mhash.h defines these...
-#undef PACKAGE
-#undef PACKAGE_BUGREPORT
-#undef PACKAGE_NAME
-#undef PACKAGE_STRING
-#undef PACKAGE_TARNAME
-#undef PACKAGE_VERSION
-#undef VERSION
-
-#include "config.h"
+#include <stdbool.h>
 
 #if ENABLE_NLS
 	#include <glib/gi18n.h>
