@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007 Tristan Heaven <tristanheaven@gmail.com>
+ *   Copyright (C) 2007-2008 Tristan Heaven <tristanheaven@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -16,6 +16,10 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#ifdef HAVE_CONFIG_H
+	#include "config.h"
+#endif
+
 #include <stdlib.h>
 #include <stdbool.h>
 #include <gtk/gtk.h>
@@ -50,16 +54,16 @@ static void load_view(GKeyFile *keyfile)
 
 	switch (view) {
 		case VIEW_FILE:
-			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(
-				gui_widget("radiomenuitem_file")), true);
+			gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(
+				gui_get_object("radiomenuitem_file")), true);
 			break;
 		case VIEW_TEXT:
-			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(
-				gui_widget("radiomenuitem_text")), true);
+			gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(
+				gui_get_object("radiomenuitem_text")), true);
 			break;
 		case VIEW_FILE_LIST:
-			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(
-				gui_widget("radiomenuitem_file_list")), true);
+			gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(
+				gui_get_object("radiomenuitem_file_list")), true);
 			break;
 		default:
 			g_assert_not_reached();
@@ -111,7 +115,7 @@ static void load_window_position(GKeyFile *keyfile)
 		error = NULL;
 	}
 
-	gtk_window_move(GTK_WINDOW(gui_widget("window")), x, y);
+	gtk_window_move(GTK_WINDOW(gui_get_widget("window")), x, y);
 }
 
 void prefs_load(void)
@@ -156,7 +160,7 @@ static void save_window_position(GKeyFile *keyfile)
 		return;
 
 	int x, y;
-	gtk_window_get_position(GTK_WINDOW(gui_widget("window")), &x, &y);
+	gtk_window_get_position(GTK_WINDOW(gui_get_widget("window")), &x, &y);
 	g_key_file_set_integer(keyfile, "window", "position_x", x);
 	g_key_file_set_integer(keyfile, "window", "position_y", y);
 }
@@ -173,7 +177,7 @@ void prefs_save(void)
 	save_window_position(keyfile);
 
 	data = g_strchug(g_key_file_to_data(keyfile, NULL, NULL));
-	g_assert(g_file_set_contents(filename, data, -1, NULL));
+	g_file_set_contents(filename, data, -1, NULL);
 
 	g_free(data);
 	g_free(filename);
